#
# spec file for package gnu-recutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lsover  1
%define _osover  0
Name:           gnu-recutils
Version:        1.9
Release:        2.1
Summary:        Text-based databases called recfiles
License:        GPL-3.0-or-later
Group:          Productivity/Databases/Tools
URL:            https://www.gnu.org/software/recutils
Source0:        https://ftp.gnu.org/gnu/recutils/recutils-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/recutils/recutils-%{version}.tar.gz.sig
Source2:        https://savannah.gnu.org/people/viewgpg.php?user_id=829#/%{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bash)
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgcrypt)
BuildRequires:  pkgconfig(uuid)

%description
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%package        devel
Summary:        Header files for %{name} libraries
Group:          Development/Languages/C and C++
Requires:       librec%{_lsover} = %{version}
Requires:       readrec%{_osover} = %{version}
Requires:       testrec%{_osover} = %{version}

%description    devel
This package contains files to develop for %{name} libraries

%package     -n librec%{_lsover}
Summary:        Text-based databases called recfiles
Group:          System/Libraries

%description -n librec%{_lsover}
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%package     -n readrec%{_osover}
Summary:        Text-based databases called recfiles
Group:          System/Libraries

%description -n readrec%{_osover}
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%package     -n testrec%{_osover}
Summary:        Text-based databases called recfiles
Group:          System/Libraries

%description -n testrec%{_osover}
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%lang_package

%prep
%setup -q -n recutils-%{version}

%build
export CFLAGS="%{optflags} -Wno-implicit-function-declaration -Wno-incompatible-pointer-types"
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang recutils %{name}.lang

%check
%make_build check

%post   -n librec%{_lsover} -p /sbin/ldconfig
%postun -n librec%{_lsover} -p /sbin/ldconfig
%post   -n readrec%{_osover} -p /sbin/ldconfig
%postun -n readrec%{_osover} -p /sbin/ldconfig
%post   -n testrec%{_osover} -p /sbin/ldconfig
%postun -n testrec%{_osover} -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS README AUTHORS
%dir %{_datadir}/recutils
%dir %{_datadir}/recutils%{_sysconfdir}
%{_bindir}/*
%{_infodir}/*%{?ext_info}
%{_mandir}/man1/*.1%{?ext_man}
%{_datadir}/recutils%{_sysconfdir}/FSD.rec

%files devel
%license COPYING
%{_includedir}/rec.h
%{_libdir}/*.so

%files -n librec%{_lsover}
%license COPYING
%{_libdir}/librec.so.%{_lsover}*

%files -n readrec%{_osover}
%license COPYING
%{_libdir}/readrec.so.%{_osover}*

%files -n testrec%{_osover}
%license COPYING
%{_libdir}/testrec.so.%{_osover}*

%files lang -f %{name}.lang
%license COPYING

%changelog
* Fri Nov 15 2024 Luigi Baldoni <aloisio@gmx.com>
- Fix Factory build
* Sun Apr 17 2022 Andreas Stieger <andreas.stieger@gmx.de>
- GNU recutils 1.9
  * Fix bug preventing recins and recset to work when /tmp is
    in a different mount point.
  * Fix a segfault that occured when csv2rec was presented with
    invalid data.
  * Fix long option name for -j/--join.
  * Format: New special field %%singular to mark fields whose
    contents must be unique in the containing record set.
  * librec: Fix a segmentation fault when there are blank
    characters before the list of fields in %%type fields.
  * Other fixes: CVE-2021-46019, CVE-2021-46022, CVE-2021-46022
- add upstream signing key and verify source signature
- drop gnu-recutils-rpmlintrc, no longer needed
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.8
  * Utilities:
    + Fix the build of readrec with recent bash headers.
  * librec:
    + Fix evaluation of sexes containing #NAME expressions.
    + Make numeric results from aggregated functions signed.
  * readred:
    + readrec --help now shows the help message and returns,
    + instead of waiting for input.
  * Emacs mode:
    + rec-mode.el now supports case-insensitive searches.
    + rec-mode.el now defines it's own faces.
    + ob-rec.el was switched to lexical binding to satisfy later
    + org-mode versions.
  * It is now possible to run the testsuite in parallel.
  * Other fixes:
    + gnulib updated.
    + Aggregate functions now work properly in Aarch64 and
    powerpc.
- Drop recutils-1.7-fix_implicit_declarations.patch,
  recutils-1.7-fix_manpages.patch and
  recutils-1.7-bash_includedirs.patch (merged upstream)
* Sun Nov  5 2017 aloisio@gmx.com
- Initial package (v1.7)
